<div class="flex justify-center mt-6">
  <a class="text-blue-400 hover:text-blue-500" href="/">Home</a>
  <span class="mx-2 text-gray-300">/</span>
  <a class="text-blue-400 hover:text-blue-500" href="{% url 'account_login' %}">Log In</a>
</div>
