@tailwind base;
@tailwind components;
@tailwind utilities;

@layer components {
  .social-github {
    @apply bg-stone-900 hover:bg-black
  }
  .social-facebook {
    @apply bg-blue-700 hover:bg-blue-800
  }
  .social-google {
    @apply bg-red-700 bg-red-800
  }
  .social-linkedin {
    @apply bg-cyan-600 bg-cyan-700
  }
}
